HashOp enum

Inheritance
Available extensions

Values

NC_MD5 → const HashOp
const HashOp(0)
NC_SHA1 → const HashOp
const HashOp(1)
NC_SHA224 → const HashOp

Windows not support

const HashOp(2)
NC_SHA256 → const HashOp
const HashOp(3)
NC_SHA384 → const HashOp
const HashOp(4)
NC_SHA512 → const HashOp
const HashOp(5)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromValue(int value) → HashOp

Constants

values → const List<HashOp>
A constant List of the values in this enum, in order of their declaration.